@@ -15,7 +15,7 @@ from collections.abc import Sequence
 
 import pkg_resources
 
-from .eval import Undetermined, cfg_interpolate
+from .eval import Undetermined, cfg_interpolate, get_config
 from .syntax import SOS_LOGLINE
 from .targets import path, sos_targets
 from .task_engines import BackgroundProcess_TaskEngine
@@ -279,10 +279,12 @@ class RemoteHost(object):
                  test_connection: bool = True) -> None:
         self.config = config
         self.cm_opts = self._get_control_master_options()
+        self.pem_opts = self._get_identify_file_options()
         self.alias = self.config['alias']
         #
         self.address = self.config['address']
         self.port = self.config.get('port', 22)
+        self.pem_file = self.config.get('pem_file', None)
         self.shared_dirs = self._get_shared_dirs()
         self.path_map = self._get_path_map()
         # we already test connect of remote hosts
@@ -341,32 +343,46 @@ class RemoteHost(object):
                     f'Failed to create ssh control master directory {master_dir}: {e}'
                 )
                 return ''
-        return f'-o "ControlMaster=auto" -o "ControlPath={master_dir}/%r@%h:%p" -o "ControlPersist=10m"'
+        return f"-o 'ControlMaster=auto' -o 'ControlPath={master_dir}/%r@%h:%p' -o 'ControlPersist=10m'"
+
+    def _get_identify_file_options(self):
+        if 'pem_file' in self.config and isinstance(
+                self.config['pem_file'],
+                str) and self.config['pem_file'].strip() != '':
+            return f''' -i '{self.config["pem_file"]}' '''
+        return ''
 
     def _get_send_cmd(self, rename=False):
         if rename:
-            return 'ssh ' + self.cm_opts + ''' -q {host} -p {port} "mkdir -p {dest:dpq}" && ''' + \
-                '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + ''' -p {port}' {source:aep} "{host}:{dest:dep}" && ''' + \
-                '''ssh ''' + self.cm_opts + ''' -q {host} -p {port} "mv {dest:dep}/{source:b} {dest:ep}" '''
-        return 'ssh ' + self.cm_opts + ''' -q {host} -p {port} "mkdir -p {dest:dpq}" && rsync -a --no-g -e 'ssh -p {port}' {source:aep} "{host}:{dest:dep}"'''
+            return 'ssh ' + self.cm_opts + self.pem_opts + ''' -q {host} -p {port} "mkdir -p {dest:dpq}" && ''' + \
+                '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + self.pem_opts + ''' -p {port}' {source:aep} "{host}:{dest:dep}" && ''' + \
+                '''ssh ''' + self.cm_opts + self.pem_opts + ''' -q {host} -p {port} "mv {dest:dep}/{source:b} {dest:ep}" '''
+        return 'ssh ' + self.cm_opts + self.pem_opts + ''' -q {host} -p {port} "mkdir -p {dest:dpq}" ''' + \
+            ''' && rsync -a --no-g -e "ssh -p {port} ''' + self.cm_opts + self.pem_opts + ''' " {source:aep} "{host}:{dest:dep}"'''
 
     def _get_receive_cmd(self, rename=False):
         if rename:
-            return '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + ''' -p {port}' {host}:{source:e} "{dest:adep}" && ''' + \
+            return '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + self.pem_opts + ''' -p {port}' {host}:{source:e} "{dest:adep}" && ''' + \
                 '''mv "{dest:adep}/{source:b}" "{dest:aep}"'''
-        return '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + ''' -p {port}' {host}:{source:e} "{dest:adep}"'''
+        return '''rsync -a --no-g -e 'ssh ''' + self.cm_opts + self.pem_opts + ''' -p {port}' {host}:{source:e} "{dest:adep}"'''
 
-    def _get_execute_cmd(self, under_workdir=True) -> str:
-        return self.config.get(
-            'execute_cmd', 'ssh ' + self.cm_opts +
-            """ -q {host} -p {port} "bash --login -c '""" +
-            (' [ -d {workdir} ] || mkdir -p {workdir}; cd {workdir} && '
-             if under_workdir else ' ') + ''' {cmd}'" ''')
+    def _get_execute_cmd(self, under_workdir=True, use_heredoc=True) -> str:
+        # #1396
+        if 'execute_cmd' in self.config:
+            return self.config['execute_cmd']
+        if use_heredoc:
+            return 'ssh ' + self.cm_opts + self.pem_opts + """ -q {host} -p {port} <<'HEREDOC!!'\nbash --login -c '""" + (
+                ' [ -d {workdir} ] || mkdir -p {workdir}; cd {workdir} && '
+                if under_workdir else ' ') + ''' {cmd} '\nHEREDOC!!\n'''
+        else:
+            return 'ssh ' + self.cm_opts + self.pem_opts + """ -q {host} -p {port} "bash --login -c '""" + (
+                ' [ -d {workdir} ] || mkdir -p {workdir}; cd {workdir} && '
+                if under_workdir else ' ') + ''' {cmd}'" '''
 
     def _get_query_cmd(self):
         return self.config.get(
-            'query_cmd', '''ssh ''' + self.cm_opts +
-            ''' -q {host} -p {port} "bash --login -c 'sos status {task} -v 0'" '''
+            'query_cmd', '''ssh ''' + self.cm_opts + self.pem_opts +
+            ''' -q {host} -p {port} "bash --login -c '{self.config.get("sos", "sos")} status {task} -v 0'" '''
         )
 
     def is_shared(self, path):
@@ -458,37 +474,35 @@ class RemoteHost(object):
 
     def test_connection(self):
         try:
-            cmd = cfg_interpolate('ssh {host} -p {port} true', {
-                'host': self.address,
-                'port': self.port
-            })
+            cmd = cfg_interpolate(
+                'ssh {host} {pf_opt} -p {port} true', {
+                    'host': self.address,
+                    'port': self.port,
+                    'pf_opt': f"-i '{self.pem_file}'" if self.pem_file else ''
+                })
             p = pexpect.spawn(cmd)
             # could be prompted for Password or password, so use assword
-            i = p.expect([
-                "(?i)are you sure you want to continue connecting",
-                "[pP]assword:", pexpect.EOF
-            ],
-                         timeout=5)
-            if i == 0:
-                p.sendline('yes')
-                p.expect([
+            while True:
+                i = p.expect([
                     "(?i)are you sure you want to continue connecting",
                     "[pP]assword:", pexpect.EOF
                 ],
-                         timeout=5)
-            elif i == 1:
-                p.close(force=True)
-                from .remote import stty_sane
-                stty_sane()
-                return f'ssh connection to {self.address} was prompted for password. Please set up public key authentication to the remote host before continue.'
-            elif i == 2:
-                p.close()
-                if p.exitstatus == 0:
-                    return 'OK'
-                elif p.before:
-                    return p.before.decode()
-                else:
-                    return f'Command "{cmd}" exits with code {p.exitstatus}'
+                             timeout=5)
+                if i == 0:
+                    p.sendline('yes')
+                elif i == 1:
+                    p.close(force=True)
+                    from .remote import stty_sane
+                    stty_sane()
+                    return f'ssh connection to {self.address} was prompted for password. Please set up public key authentication to the remote host before continue.'
+                elif i == 2:
+                    p.close()
+                    if p.exitstatus == 0:
+                        return 'OK'
+                    elif p.before:
+                        return p.before.decode()
+                    else:
+                        return f'Command "{cmd}" exits with code {p.exitstatus}'
         except pexpect.TIMEOUT:
             return f'ssh connection to {self.address} time out with prompt: {str(p.before)}'
         except Exception as e:
@@ -804,9 +818,9 @@ class RemoteHost(object):
 
     def send_job_file(self, job_file, dir='tasks'):
         send_cmd = cfg_interpolate(
-            f'ssh {self.cm_opts}'
+            f'ssh {self.cm_opts + self.pem_opts}'
             f' -q {{address}} -p {{port}} "[ -d ~/.sos/{dir} ] || mkdir -p ~/.sos/{dir}" && '
-            f' rsync --ignore-existing -a --no-g -e "ssh {self.cm_opts}'
+            f' rsync --ignore-existing -a --no-g -e "ssh {self.cm_opts + self.pem_opts}'
             f' -q -p {{port}}" {{job_file:ap}} {{address}}:.sos/{dir}/', {
                 'job_file': sos_targets(job_file),
                 'address': self.address,
@@ -820,18 +834,21 @@ class RemoteHost(object):
                 f'Failed to copy job {job_file} to {self.alias} using command {send_cmd}: {e}'
             )
 
-    def check_output(self, cmd: object, under_workdir=False,
+    def check_output(self,
+                     cmd: object,
+                     under_workdir=False,
                      **kwargs) -> object:
         if isinstance(cmd, list):
             cmd = subprocess.list2cmdline(cmd)
         try:
             cmd = cfg_interpolate(
-                self._get_execute_cmd(under_workdir=under_workdir), {
-                    'host': self.address,
-                    'port': self.port,
-                    'cmd': cmd,
-                    'workdir': self._map_var(os.getcwd())
-                })
+                self._get_execute_cmd(
+                    under_workdir=under_workdir, use_heredoc="." in cmd), {
+                        'host': self.address,
+                        'port': self.port,
+                        'cmd': cmd.replace("'", r"'\''"),
+                        'workdir': self._map_var(os.getcwd())
+                    })
         except Exception as e:
             raise ValueError(
                 f'Failed to run command {cmd}: {e} ({env.sos_dict["CONFIG"]})')
@@ -848,12 +865,13 @@ class RemoteHost(object):
             cmd = subprocess.list2cmdline(cmd)
         try:
             cmd = cfg_interpolate(
-                self._get_execute_cmd(under_workdir=under_workdir), {
-                    'host': self.address,
-                    'port': self.port,
-                    'cmd': cmd,
-                    'workdir': self._map_var(os.getcwd())
-                })
+                self._get_execute_cmd(
+                    under_workdir=under_workdir, use_heredoc="." in cmd), {
+                        'host': self.address,
+                        'port': self.port,
+                        'cmd': cmd.replace("'", r"'\''"),
+                        'workdir': self._map_var(os.getcwd())
+                    })
         except Exception as e:
             raise ValueError(f'Failed to run command {cmd}: {e}')
         if 'TASK' in env.config['SOS_DEBUG'] or 'ALL' in env.config['SOS_DEBUG']:
@@ -869,12 +887,13 @@ class RemoteHost(object):
             cmd = subprocess.list2cmdline(cmd)
         try:
             cmd = cfg_interpolate(
-                self._get_execute_cmd(under_workdir=False), {
-                    'host': self.address,
-                    'port': self.port,
-                    'cmd': cmd,
-                    'workdir': self._map_var(os.getcwd())
-                })
+                self._get_execute_cmd(
+                    under_workdir=False, use_heredoc="." in cmd), {
+                        'host': self.address,
+                        'port': self.port,
+                        'cmd': cmd.replace("'", r"'\''"),
+                        'workdir': self._map_var(os.getcwd())
+                    })
         except Exception as e:
             raise ValueError(f'Failed to run command {cmd}: {e}')
         if 'TASK' in env.config['SOS_DEBUG'] or 'ALL' in env.config['SOS_DEBUG']:
@@ -896,12 +915,13 @@ class RemoteHost(object):
         sys_task_dir = os.path.join(os.path.expanduser('~'), '.sos', 'tasks')
         # use -p to preserve modification times so that we can keep the job status locally.
         receive_cmd = cfg_interpolate(
-            "scp -P {port} -p -q {address}:.sos/tasks/{task}.* {sys_task_dir}",
+            "scp -P {port} {pem_opts} -p -q {address}:.sos/tasks/{task}.* {sys_task_dir}",
             {
                 'port': self.port,
                 'address': self.address,
                 'task': task_id,
-                'sys_task_dir': sys_task_dir
+                'sys_task_dir': sys_task_dir,
+                'pem_opts': self.pem_opts,
             })
         # it is possible that local files are readonly (e.g. a pluse file) so we first need to
         # make sure the files are readable and remove them. Also, we do not want any file that is
@@ -1051,21 +1071,22 @@ class Host:
                 return host
         for host, host_info in env.sos_dict['CONFIG']['hosts'].items():
             # find by key hostname
-            if 'hostname' in host_info and (
-                    host_info['hostname'].lower().split('.')[0] == hostname or
-                    host_info['hostname'].lower() == hostname.split('.')[0]):
-                return host
+            if 'hostname' in host_info:
+                hn = get_config(
+                    'hosts', host, 'hostname', expected_type=str).lower()
+                if hn.split('.')[0] == hostname or hn == hostname.split('.')[0]:
+                    return host
         for host, host_info in env.sos_dict['CONFIG']['hosts'].items():
             # find by alias
             if host.lower() == hostname:
                 return host
         for host, host_info in env.sos_dict['CONFIG']['hosts'].items():
             # find by address
-            if 'address' in host_info and (
-                    host_info['address'].split('@')[-1].lower() == hostname or
-                    host_info['address'].split(
-                        '.', 1)[0].split('@')[-1].lower() == hostname):
-                return host
+            if 'address' in host_info:
+                addr = get_config('hosts', host, 'address', expected_type=str)
+                if addr.split('@')[-1].lower() == hostname or addr.split(
+                        '.', 1)[0].split('@')[-1].lower() == hostname:
+                    return host
         # try IP Address
         hostname = socket.gethostname()
         ips = socket.gethostbyname_ex(hostname)[2]
@@ -1073,9 +1094,10 @@ class Host:
         # if the IP matches any address?
         for host, host_info in env.sos_dict['CONFIG']['hosts'].items():
             # find by key hostname
-            if 'address' in host_info and any(
-                    ip == host_info['address'].split('@')[-1] for ip in ips):
-                return host
+            if 'address' in host_info:
+                addr = get_config('hosts', host, 'address', expected_type=str)
+                if any(ip == addr.split('@')[-1] for ip in ips):
+                    return host
         # now check if a key localhost is defined
         if 'localhost' in env.sos_dict['CONFIG']:
             if env.sos_dict['CONFIG']['localhost'] not in env.sos_dict[
@@ -1128,14 +1150,15 @@ class Host:
             if REMOTE not in env.sos_dict['CONFIG']['hosts']:
                 raise ValueError(f'Undefined remote host {REMOTE}')
 
-            # now we have definition for local and remote hosts
+            # now we have definition for local and remote hosts but we only
+            # exapnd address, which we have to know right now
             cfg = env.sos_dict['CONFIG']['hosts']
-            self.config = {
-                x: y
-                for x, y in cfg[self.alias].items()
-                if x not in ('paths', 'shared')
-            }
-
+            self.config = get_config(
+                'hosts',
+                self.alias,
+                excluded_keys=('paths', 'shared'),
+                expand_keys=('address', 'port', 'pem_file'),
+                expected_type=dict)
             # if local and remote hosts are the same
             if LOCAL == REMOTE or 'address' not in env.sos_dict['CONFIG'][
                     'hosts'][REMOTE] or (
@@ -1158,12 +1181,15 @@ class Host:
                     common = set(cfg[LOCAL]['shared'].keys()) & set(
                         cfg[REMOTE]['shared'].keys())
                     if common:
+                        lcl_shrd = get_config(
+                            'hosts', LOCAL, 'shared', expected_type=dict)
+                        rmt_shrd = get_config(
+                            'hosts', REMOTE, 'shared', expected_type=dict)
                         self.config['shared'] = [
-                            normalize_value(cfg[LOCAL]['shared'][x])
-                            for x in common
+                            normalize_value(lcl_shrd[x]) for x in common
                         ]
                         self.config['path_map'] = [
-                            f'{normalize_value(cfg[LOCAL]["shared"][x])} -> {normalize_value(cfg[REMOTE]["shared"][x])}'
+                            f'{normalize_value(lcl_shrd[x])} -> {normalize_value(rmt_shrd[x])}'
                             for x in common
                         ]
                 # if paths are defined for both local and remote host, define path_map
@@ -1176,11 +1202,31 @@ class Host:
                             f'One or more local paths {", ".join(cfg[LOCAL]["paths"].keys())} cannot be mapped to remote host {REMOTE} with paths {",".join(cfg[REMOTE]["paths"].keys())}'
                         )
                     #
+                    lpaths = get_config(
+                        'hosts', LOCAL, 'paths', expected_type=dict)
+                    rpaths = get_config(
+                        'hosts', REMOTE, 'paths', expected_type=dict)
                     self.config['path_map'].extend([
-                        f'{normalize_value(cfg[LOCAL]["paths"][x])} -> {normalize_value(cfg[REMOTE]["paths"][x])}'
-                        for x in cfg[LOCAL]['paths'].keys()
-                        if x in cfg[REMOTE]['paths']
+                        f'{normalize_value(lpaths[x])} -> {normalize_value(rpaths[x])}'
+                        for x in lpaths.keys()
+                        if x in rpaths
                     ])
+                if 'pem_file' in cfg[LOCAL]:
+                    if isinstance(cfg[LOCAL]['pem_file'], dict):
+                        if REMOTE in cfg[LOCAL]['pem_file']:
+                            self.config['pem_file'] = get_config(
+                                'hosts',
+                                LOCAL,
+                                'pem_file',
+                                REMOTE,
+                                expected_type=str)
+                    elif isinstance(cfg[LOCAL]['pem_file'], str):
+                        self.config['pem_file'] = get_config(
+                            'hosts', LOCAL, 'pem_file', expected_type=str)
+                    else:
+                        raise ValueError(
+                            f"Option pem_file should be a string or dictionary, {cfg[LOCAL]['pem_file']} provided."
+                        )
         elif LOCAL == REMOTE:
             # now we have checked local and remote are not defined, but they are the same, so
             # it is safe to assume that they are both local hosts
