@@ -213,6 +213,7 @@ def test_paths(host):
             host.send_to_host(os.path.join(local, f".sos_test_{tID}.txt"))
         except Exception as e:
             return f'Failed to send files under {local} to remote host under {remote}: {e}'
+
         # the file should be available on remote host
         try:
             remote_content = host.check_output(
@@ -283,16 +284,18 @@ def stty_sane():
         pass
 
 
-def test_queue(host, cmd=None):
+def test_queue(host, cmd=None, verbosity=1):
     try:
         h = Host(host, start_engine=False)
-    except Exception:
+    except Exception as e:
+        if verbosity > 2:
+            env.logger.warning(e)
         return [host, '?', '?', '-', '-', '-', '-', '-']
     ssh_res = test_ssh(h._host_agent)
     return [
         h.alias, h._host_agent.address, h._engine_type, ssh_res,
         test_scp(h._host_agent) if ssh_res.startswith('OK') else '-',
-        test_cmd(h._host_agent, ["sos", "-h"])
+        test_cmd(h._host_agent, [h.config.get("sos", "sos"), "-h"])
         if ssh_res.startswith('OK') else '-',
         test_paths(h._host_agent) if ssh_res.startswith('OK') else '-',
         test_shared(h._host_agent) if ssh_res.startswith('OK') else '-'
@@ -300,7 +303,7 @@ def test_queue(host, cmd=None):
 
 
 def test_queues(cfg, hosts=[], cmd=None, verbosity=1):
-    env.verbosity = 1
+    env.verbosity = verbosity
     all_hosts = cfg.get('hosts', [])
     if not all_hosts:
         env.logger.warning(
@@ -321,7 +324,8 @@ def test_queues(cfg, hosts=[], cmd=None, verbosity=1):
         return
     from multiprocessing import Pool
     pool = Pool(min(len(hosts), 10))
-    host_description.extend(pool.starmap(test_queue, [(x, cmd) for x in hosts]))
+    host_description.extend(
+        pool.starmap(test_queue, [(x, cmd, verbosity) for x in hosts]))
     if verbosity == 0:
         # just print succ or self
         for hd in host_description:
@@ -425,6 +429,27 @@ def copy_public_key(host, agent, password):
     return 'OK'
 
 
+def create_public_key():
+    try:
+        cmd = 'ssh-keygen -t rsa'
+        env.logger.info(cmd)
+        p = pexpect.spawn(cmd, echo=False)
+        while True:
+            i = p.expect([
+                "Enter file in which to save .*", "Enter passphrase.*",
+                "Enter same passphrase again:.*", 'Overwrite .*', pexpect.EOF
+            ])
+            if i in (0, 1, 2):
+                p.sendline('')
+            elif i == 3:
+                p.sendline('y')
+            elif i == 4:
+                break
+    except Exception as e:
+        p.close()
+        raise RuntimeError(f'Failed to create a public key: {e}')
+
+
 def setup_remote_access(cfg, hosts=[], password='', verbosity=1):
     env.verbosity = verbosity
     all_hosts = cfg.get('hosts', [])
@@ -459,23 +484,17 @@ def setup_remote_access(cfg, hosts=[], password='', verbosity=1):
             else:
                 host_agent = Namespace(address=host, port=22)
         except Exception as e:
-            env.logger.error(f'Failed to start task engine {host}: {e}')
+            env.logger.error(
+                f'Failed to start set up remote engine for {host}: {e}')
             continue
 
         if os.path.isfile(public_key):
             env.logger.info('Using existing public key .ssh/id_rsa.pub')
         else:
             env.logger.info(f'Public key {public_key} is found. Creating one.')
-            try:
-                subprocess.check_output(
-                    'echo | ssh-keygen -t rsa',
-                    shell=True,
-                    stderr=subprocess.STDOUT).decode()
-                if not os.path.isfile(public_key):
-                    raise RuntimeError('public key not found after ssh-keygen')
-            except subprocess.CalledProcessError as e:
-                print(e.output.decode())
-                raise RuntimeError(f'Failed to create public key: {e}')
+            create_public_key()
+            if not os.path.isfile(public_key):
+                raise RuntimeError('Failed to create public key.')
         #
         response = copy_public_key(host, host_agent, password)
         stty_sane()
@@ -484,7 +503,8 @@ def setup_remote_access(cfg, hosts=[], password='', verbosity=1):
             sys.exit(1)
         # file copied, check ssh again.
         if isinstance(host_agent, Namespace):
-            host_agent = Host(host, start_engine=False, test_connection=False)._host_agent
+            host_agent = Host(
+                host, start_engine=False, test_connection=False)._host_agent
         response = test_ssh(host_agent)
         if response.startswith('OK'):
             env.logger.info(
