@@ -23,7 +23,7 @@ import pkg_resources
 
 from .utils import (Error, env, pickleable, short_repr, stable_repr)
 from .pattern import extract_pattern
-from .eval import interpolate
+from .eval import interpolate, get_config
 from .controller import request_answer_from_controller, send_message_to_controller
 
 try:
@@ -624,7 +624,7 @@ class path(type(Path())):
         if 'paths' not in env.sos_dict['CONFIG']['hosts'][host]:
             return []
         else:
-            return list(env.sos_dict['CONFIG']['hosts'][host]['paths'].keys())
+            return list(get_config(['hosts', host, 'paths']).keys())
 
     def _init(self, template=None):
         super(path, self)._init(template)
@@ -646,10 +646,13 @@ class path(type(Path())):
             return self
         try:
             return self._from_parts([
-                env.sos_dict['CONFIG']['hosts']
-                [env.sos_dict.get('__host__', 'localhost'
-                                 ) if host is None else host]['paths'][
-                                     self._parts[0][1:]]
+                get_config(
+                    'hosts',
+                    env.sos_dict.get('__host__', 'localhost'
+                                    ) if host is None else host,
+                    'paths',
+                    self._parts[0][1:],
+                    expected_type=str)
             ] + self._parts[1:])
         except Exception:
             if host is None and '__host__' not in env.sos_dict:
@@ -1384,7 +1387,6 @@ class sos_targets(BaseTarget, Sequence, os.PathLike):
 
     def __getitem__(self, i):
         if isinstance(i, str):
-            env.logger.error(f'get {i}')
             ret = sos_targets()
             ret._undetermined = self._undetermined
             ret._targets = [
@@ -1405,6 +1407,8 @@ class sos_targets(BaseTarget, Sequence, os.PathLike):
                         if y == i
                     ],
                                labels=i).set(**grp._dict))
+            if not ret._targets:
+                env.logger.warning(f'No target with label "{i}" is available.')
             return ret
         else:
             return self._targets[i]
@@ -1435,7 +1439,8 @@ class sos_targets(BaseTarget, Sequence, os.PathLike):
                     )
             else:
                 raise AttributeError(
-                    f'{self.__class__.__name__} object has no attribute {name}')
+                    f'{self.__class__.__name__} object of length {len(self)} has no attribute {name}'
+                )
 
     def target_name(self):
         return f"sos_targets([{','.join(x.target_name() for x in self._targets)}],_labels=[{','.join(self._labels)}])"
