@@ -1410,41 +1410,10 @@ def load_config_files(filename=None):
     for v in cfg.values():
         if isinstance(v, dict):
             process_based_on(cfg, v)
-    # interpolation
-    def interpolate_value(cfg, item):
-        res = {}
-        for k, v in item.items():
-            if isinstance(v, dict):
-                # v should be processed in place
-                res[k] = interpolate_value(cfg, v)
-            elif isinstance(v, str) and '{' in v and '}' in v and not (
-                    k.endswith('_template') or k.endswith('_cmd')):
-                try:
-                    res[k] = eval(
-                        as_fstring(v), copy.copy(item), copy.copy(cfg))
-                except Exception as e:
-                    # we do not care about other places when interpolation fails
-                    env.logger.debug(f'Failed to interpolate {k}={v}: {e}')
-                    res[k] = v
-            else:
-                res[k] = v
-        return res
 
-    #
-    res = {}
-    for k, v in cfg.items():
-        if isinstance(v, dict):
-            res[k] = interpolate_value(cfg, v)
-        elif isinstance(v, str) and '{' in v and '}' in v:
-            try:
-                res[k] = eval(as_fstring(v), copy.copy(cfg))
-            except Exception:
-                res[k] = v
-        else:
-            res[k] = v
-    config_cache[(filename, filemtime, extra_cfg)] = res
-    env.sos_dict.set('CONFIG', res)
-    return res
+    config_cache[(filename, filemtime, extra_cfg)] = cfg
+    env.sos_dict.set('CONFIG', cfg)
+    return cfg
 
 
 def format_duration(time_diff_secs, short=True):
@@ -1917,8 +1886,17 @@ def get_nodelist():
         env.log_to_file('WORKER', f'Using "-j {args}" on a PBS cluster.')
         return args
     elif "PE_HOSTFILE" in os.environ:
+        # The pathname of a file containing a  detailed  descrip-
+        #  tion  of  the  layout of the parallel environment to be
+        #  setup by the start-up procedure. Each line of the  file
+        #  refers  to a host on which parallel processes are to be
+        #  run. The first entry of each line denotes the hostname,
+        #  the second entry the number of parallel processes to be
+        #  run on the host, the third entry the name of the queue,
+        #  and  the  fourth  entry a processor range to be used in
+        #  case of a multiprocessor machine.
         with open(os.environ["PE_HOSTFILE"], 'r') as hosts:
-            args = [':'.join(host.split()) for host in hosts]
+            args = [':'.join(host.split()[:2]) for host in hosts]
         env.log_to_file('WORKER', f'Using "-j {args}" on a SGE cluster.')
         return args
     elif "LSB_MCPU_HOSTS" in os.environ:
