@@ -48,7 +48,7 @@ class TestRemote(unittest.TestCase):
             file_target(f).unlink()
 
     @unittest.skipIf(not has_docker, "Docker container not usable")
-    def testRemoteExecute(self):
+    def test_remote_execute(self):
         if os.path.isfile('result_remote.txt'):
             os.remove('result_remote.txt')
         if os.path.isfile('local.txt'):
@@ -107,7 +107,7 @@ run:
 # [1]
 # sh:
 #    echo "1" > 1.txt
-# 
+#
 # [10]
 # task: to_host={'1.txt': '2.txt'}, from_host={'3.txt': '2.txt'}
 # with open('2.txt', 'a') as t:
@@ -127,7 +127,7 @@ run:
 #             self.assertEqual('1\n2\n', content, 'Got {}'.format(content))
 
     @unittest.skipIf(not has_docker, "Docker container not usable")
-    def testFromHostOption(self):
+    def test_from_host_option(self):
         '''Test from_remote option'''
         if os.path.isfile('llp'):
             os.remove('llp')
@@ -148,29 +148,29 @@ with open('llp', 'w') as llp:
             }).run()
         self.assertTrue(os.path.isfile('llp'))
 
-    @unittest.skipIf(not has_docker, "Docker container not usable")
-    def testFromHostOptionDict(self):
-        # dict form
-        if os.path.isfile('llp'):
-            os.remove('llp')
+#     @unittest.skipIf(not has_docker, "Docker container not usable")
+#     def test_from_host_option_dict(self):
+#         # dict form
+#         if os.path.isfile('llp'):
+#             os.remove('llp')
 
-        script = SoS_Script('''
-[10]
-task: from_host={'llp': 'll'}
-with open('llp', 'w') as llp:
-    llp.write("LLP")
-''')
-        wf = script.workflow()
-        Base_Executor(
-            wf,
-            config={
-                'config_file': '~/docker.yml',
-                'default_queue': 'docker',
-            }).run()
-        self.assertTrue(os.path.isfile('llp'))
+#         script = SoS_Script('''
+# [10]
+# task: from_host={'llp': 'll'}
+# with open('llp', 'w') as llp:
+#     llp.write("LLP")
+# ''')
+#         wf = script.workflow()
+#         Base_Executor(
+#             wf,
+#             config={
+#                 'config_file': '~/docker.yml',
+#                 'default_queue': 'docker',
+#             }).run()
+#         self.assertTrue(os.path.isfile('llp'))
 
     @unittest.skipIf(not has_docker, "Docker container not usable")
-    def testLocalFromHostOption(self):
+    def test_local_from_host_option(self):
         '''Test from_remote option'''
         if os.path.isfile('llp'):
             os.remove('llp')
@@ -193,6 +193,8 @@ sh:
         self.assertTrue(os.path.isfile('llp'))
         os.remove('llp')
         # dict form is deprecated
+
+
 #         script = SoS_Script('''
 # [10]
 # task: from_host={'llp': 'll'}
@@ -212,7 +214,7 @@ sh:
 #         self.assertTrue(os.path.isfile('llp'))
 #         os.remove('llp')
 
-    def testWorkerProcs(self):
+    def test_worker_procs(self):
         # test -j option
         script = SoS_Script('''
 [1]
@@ -229,7 +231,7 @@ bash: expand=True
                 'worker_proces': ['1', 'localhost:2']
             }).run()
 
-    def testWorkerProcsWithTask(self):
+    def test_worker_procs_with_task(self):
         # test -j option
         script = SoS_Script('''
 [1]
